==> haskell-listlike-4.6.2-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-listlike.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ListLike
version: 4.6.2
id: ListLike-4.6.2-9u59oyLRo3e77IpTeBZhxJ
key: ListLike-4.6.2-9u59oyLRo3e77IpTeBZhxJ
license: BSD-3-Clause
copyright: Copyright (c) 2007-2008 John Goerzen
maintainer: David Fox <dsf@seereason.com>
author: John Goerzen
stability: Stable
homepage: http://github.com/JohnLato/listlike
synopsis: Generalized support for list-like structures
description:
    Generalized support for list-like structures in Haskell.
    .
    The ListLike module provides a common interface to the various Haskell
    types that are list-like.  Predefined interfaces include standard
    Haskell lists, Arrays, ByteStrings, and lazy ByteStrings.  Custom
    types can easily be made ListLike instances as well.
    .
    ListLike also provides for String-like types, such as String and
    ByteString, for types that support input and output, and for types that can handle
    infinite lists.
category: list, string, text, bytestring, vector
abi: 8ae98fb0de68e300f0a40c1364660567
exposed: True
exposed-modules:
    Data.ListLike Data.ListLike.Base Data.ListLike.CharString
    Data.ListLike.Chars Data.ListLike.DList Data.ListLike.FMList
    Data.ListLike.FoldableLL Data.ListLike.IO Data.ListLike.Instances
    Data.ListLike.String Data.ListLike.Text Data.ListLike.Text.Builder
    Data.ListLike.Text.Text Data.ListLike.Text.TextLazy
    Data.ListLike.UTF8 Data.ListLike.Utils Data.ListLike.Vector
    Data.ListLike.Vector.Generic Data.ListLike.Vector.Storable
    Data.ListLike.Vector.Unboxed Data.ListLike.Vector.Vector
import-dirs: /usr/lib/ghc-8.6.5/site-local/ListLike-4.6.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/ListLike-4.6.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/ListLike-4.6.2
hs-libraries: HSListLike-4.6.2-9u59oyLRo3e77IpTeBZhxJ
depends:
    array-0.5.3.0 base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    deepseq-1.4.4.0 dlist-0.8.0.6-CQRMCGRgL5B3ZxhntX4iOr
    fmlist-0.9.2-2wB8okaNnKpJPuHuWwT7AH text-1.2.3.1
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-listlike/html/ListLike.haddock
haddock-html: /usr/share/doc/haskell-listlike/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-listlike-4.6.2-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-listlike.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ListLike
version: 4.6.2
id: ListLike-4.6.2-C4CFrHBIgxr6EibNXiLNEb
key: ListLike-4.6.2-C4CFrHBIgxr6EibNXiLNEb
license: BSD-3-Clause
copyright: Copyright (c) 2007-2008 John Goerzen
maintainer: David Fox <dsf@seereason.com>
author: John Goerzen
stability: Stable
homepage: http://github.com/JohnLato/listlike
synopsis: Generalized support for list-like structures
description:
    Generalized support for list-like structures in Haskell.
    .
    The ListLike module provides a common interface to the various Haskell
    types that are list-like.  Predefined interfaces include standard
    Haskell lists, Arrays, ByteStrings, and lazy ByteStrings.  Custom
    types can easily be made ListLike instances as well.
    .
    ListLike also provides for String-like types, such as String and
    ByteString, for types that support input and output, and for types that can handle
    infinite lists.
category: list, string, text, bytestring, vector
abi: 9c4ee51b0409b3ffab9871a57786610d
exposed: True
exposed-modules:
    Data.ListLike Data.ListLike.Base Data.ListLike.CharString
    Data.ListLike.Chars Data.ListLike.DList Data.ListLike.FMList
    Data.ListLike.FoldableLL Data.ListLike.IO Data.ListLike.Instances
    Data.ListLike.String Data.ListLike.Text Data.ListLike.Text.Builder
    Data.ListLike.Text.Text Data.ListLike.Text.TextLazy
    Data.ListLike.UTF8 Data.ListLike.Utils Data.ListLike.Vector
    Data.ListLike.Vector.Generic Data.ListLike.Vector.Storable
    Data.ListLike.Vector.Unboxed Data.ListLike.Vector.Vector
import-dirs: /usr/lib/ghc-8.6.5/site-local/ListLike-4.6.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/ListLike-4.6.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/ListLike-4.6.2
hs-libraries: HSListLike-4.6.2-C4CFrHBIgxr6EibNXiLNEb
depends:
    array-0.5.3.0 base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    deepseq-1.4.4.0 dlist-0.8.0.6-Cxrf3wOfeJW535RKj0Gaep
    fmlist-0.9.2-2wB8okaNnKpJPuHuWwT7AH text-1.2.3.1
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-listlike/html/ListLike.haddock
haddock-html: /usr/share/doc/haskell-listlike/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
